@@ -10,6 +10,8 @@ import requests
 import threading
 import typing
 import random
+
+from diem.__VERSION__ import VERSION
 from concurrent.futures import Future, ThreadPoolExecutor, as_completed
 from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey
 
@@ -25,6 +27,8 @@ DEFAULT_RETRY_DELAY: float = 0.2
 DEFAULT_WAIT_FOR_TRANSACTION_TIMEOUT_SECS: float = 30.0
 DEFAULT_WAIT_FOR_TRANSACTION_WAIT_DURATION_SECS: float = 0.2
 
+USER_AGENT_HTTP_HEADER: str = "diem-client-sdk-python / %s" % VERSION
+
 
 class JsonRpcError(Exception):
     pass
@@ -187,6 +191,7 @@ class Client:
     ) -> None:
         self._url: str = server_url
         self._session: requests.Session = session or requests.Session()
+        self._session.headers.update({"User-Agent": USER_AGENT_HTTP_HEADER})
         self._timeout: typing.Tuple[float, float] = timeout or (DEFAULT_CONNECT_TIMEOUT_SECS, DEFAULT_TIMEOUT_SECS)
         self._last_known_server_state: State = State(chain_id=-1, version=-1, timestamp_usecs=-1)
         self._lock = threading.Lock()
